# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_chat_get_with_members_and_messages import ResponseWrapperChatGetWithMembersAndMessages  # noqa: E501

class TestResponseWrapperChatGetWithMembersAndMessages(unittest.TestCase):
    """ResponseWrapperChatGetWithMembersAndMessages unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatGetWithMembersAndMessages:
        """Test ResponseWrapperChatGetWithMembersAndMessages
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatGetWithMembersAndMessages`
        """
        model = ResponseWrapperChatGetWithMembersAndMessages()  # noqa: E501
        if include_optional:
            return ResponseWrapperChatGetWithMembersAndMessages(
                done = True,
                result = chat_server_connector.models.chat_get_with_members_and_messages.ChatGetWithMembersAndMessages(
                    id = 56, 
                    uuid = '', 
                    chat_type = 'SOLO', 
                    avatar_id = '', 
                    name = '', 
                    description = '', 
                    messaging_enabled = True, 
                    permalink_enabled = True, 
                    is_muted = True, 
                    created_at = 56, 
                    last_updated_at = 56, 
                    members = [
                        chat_server_connector.models.chat_member_get.ChatMemberGet(
                            role = null, 
                            user_id = 56, 
                            bot_id = 56, 
                            id = 56, 
                            chat_id = 56, 
                            added_at = 56, 
                            last_seen_at = 56, 
                            is_removed = True, 
                            is_banned = True, 
                            is_muted = True, 
                            user = chat_server_connector.models.contact.Contact(
                                id = 56, 
                                role = 1, 
                                nickname = '', 
                                personal_description = '', 
                                first_name = '', 
                                last_name = '', 
                                avatar_id = '', 
                                is_online = True, 
                                address = null, 
                                phone_number = '', 
                                is_public_email = True, 
                                is_public_phone_number = True, 
                                is_public_city = True, 
                                is_public_country = True, 
                                email = '', ), 
                            bot = chat_server_connector.models.ai_assistant_get.AiAssistantGet(
                                id = 56, 
                                is_active = True, 
                                conversation_style = 'formal', 
                                function = 'support', 
                                avatar_id = '', 
                                voice_id = 56, 
                                name = '', 
                                allow_text = True, 
                                allow_voice = True, 
                                prefer_voice = True, 
                                system_prompt = '', 
                                system_prompt_support = '', 
                                system_prompt_tutor = '', 
                                conversation_starter = '', 
                                created_at = 56, 
                                last_updated_at = 56, 
                                deleted_at = 56, 
                                is_available = True, 
                                goals = [
                                    chat_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                                        id = 56, 
                                        ai_assistant_id = 56, 
                                        is_active = True, 
                                        engagement_preset_id = 56, 
                                        engagement = 56, 
                                        max_total_engagement_count = 56, 
                                        max_engagement_count = 56, 
                                        max_engagement_period = 56, 
                                        engagement_opt_out_duration = 56, 
                                        name = '', 
                                        page_url = '', 
                                        primary_course_id = 56, 
                                        course_ids = [
                                            56
                                            ], 
                                        additional_prompt = '', 
                                        created_at = 56, 
                                        last_updated_at = 56, 
                                        engagement_preset = chat_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                            id = 56, 
                                            order = 56, 
                                            name = '', 
                                            engagement = 56, 
                                            max_total_engagement_count = 56, 
                                            max_engagement_count = 56, 
                                            max_engagement_period = 56, 
                                            engagement_opt_out_duration = 56, 
                                            created_at = 56, ), 
                                        is_fullfilled = True, 
                                        interactions_summary = chat_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                            total_interaction_count = 56, 
                                            recent_interaction_count = 56, 
                                            last_opt_out_at = 56, 
                                            last_engagement_at = 56, 
                                            is_available = True, ), 
                                        primary_course = chat_server_connector.models.course_public.CoursePublic(
                                            id = 56, 
                                            title = '', 
                                            description = '', 
                                            url = '', 
                                            payment_type = 'paid', 
                                            modules = [
                                                chat_server_connector.models.course_module_public.CourseModulePublic(
                                                    id = 56, 
                                                    title = '', 
                                                    public_description = '', 
                                                    short_description = '', 
                                                    lessons = [
                                                        chat_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                            id = 56, 
                                                            title = '', )
                                                        ], )
                                                ], ), )
                                    ], ), )
                        ], 
                    messages = [
                        chat_server_connector.models.chat_message.ChatMessage(
                            text = '', 
                            file_id = '', 
                            id = 56, 
                            chat_id = 56, 
                            chat_member_id = 56, 
                            chat_session_id = 56, 
                            is_hidden = True, 
                            inserted_by_member_id = 56, 
                            chat_message_type = null, 
                            added_at = 56, 
                            deleted_at = 56, )
                        ], ),
                error = ''
            )
        else:
            return ResponseWrapperChatGetWithMembersAndMessages(
                done = True,
        )
        """

    def testResponseWrapperChatGetWithMembersAndMessages(self):
        """Test ResponseWrapperChatGetWithMembersAndMessages"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
